##############################
Product Image Attribute Module
##############################

The *Product Image Attribute Module* adds attributes to product images.

.. toctree::
   :maxdepth: 2

   design
